==> aiocrawler-1.20.tar.gz: aiocrawler-1.20/README.md <==
! [ v e r s i o n ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / v e r s i o n - v 1 . 1 8 - g r e e n . s v g ) 
 
 ! [ s u p p o r t ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / p y t h o n - 3 . 6 % 2 0 % 7 C % 2 0 3 . 7 - b l u e . s v g ) 
 
 ! [ l i c e n s e ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / l i c e n s e - M I T - y e l l o w . s v g ) 
 
 
 
 # # # #   A i o c r a w l e r   i s   a n   a s y n c h r o n o u s ,   d i s t r i b u t e d   c r a w l e r   f r a m e w o r k ,   b a s e d   o n   r e d i s ,   a s y n c i o ,   a i o h t t p . 
 
 * * D i f f e r e n t   f r o m   s c r a p y ,   A i o c r a w l e r   s t a r t s   w i t h   a   s e r i e s   o f   w o r d s , 
 
 g e n e r a t e s   u r l s   b a s e d   o n   w o r d s   a n d   s t a r t s   c r a w l i n g   i n s t e a d   o f 
 
 s t a r t _ u r l s * * 
 
 
 
 ! [ i m a g e ] ( h t t p s : / / g i t h u b . c o m / k y l i n 1 0 2 0 / a i o c r a w l e r - d e m o / b l o b / m a s t e r / c r e d i t . g i f ) 
 
 
 
 
 
 -   [ -Neech] [ d o c _ c n ]   |   [ d o c u m e n t a t i o n ] [ d o c _ e n ] 
 
 -   # # #   I n s t a l l a t i o n 
 
 ` ` ` b a s h 
 
 p i p 3   i n s t a l l   a i o c r a w l e r 
 
 ` ` ` 
 
 Y o u   c a n   a l s o   i n s t a l l   b y   t h i s   w a y 
 
 ` ` ` b a s h 
 
 p y t h o n 3   s e t u p . p y   i n s t a l l 
 
 ` ` ` 
 
 
 
 -   # # #   s t a r t   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   s t a r t p r o j e c t   d e m o 
 
 ` ` ` 
 
 * * T h i s   w i l l   c r e a t e   a   d e m o   d i r e c t o r y   w i t h   t h e   f o l l o w i n g   c o n t e n t s * * 
 
 ` ` ` 
 
 + - -   d e m o / 
 
 |         + - -   i t e m s . p y 
 
 |         + - -   m i d d l e w a r e s . p y 
 
 |         + - -   r u n . p y 
 
 |         + - -   s e t t i n g s . p y 
 
 |         + - -   s p i d e r s . p y 
 
 ` ` ` 
 
 * * T h i s   i s   t h e   c o d e   f o r   y o u r   f i r s t   S p i d e r * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s ,   S p i d e r ,   R e q u e s t 
 
 
 
 
 
 c l a s s   D e m o S p i d e r ( S p i d e r ) : 
 
         n a m e   =   " d e m o " 
 
 
 
         d e f   _ _ i n i t _ _ ( s e l f ,   s e t t i n g s :   B a s e S e t t i n g s ) : 
 
                 S p i d e r . _ _ i n i t _ _ ( s e l f ,   s e t t i n g s ) 
 
 
 
         d e f   m a k e _ r e q u e s t ( s e l f ,   w o r d ) : 
 
                 r e t u r n   R e q u e s t ( w o r d ,   c a l l b a c k = s e l f . p a r s e ) 
 
 
 
         d e f   p a r s e ( s e l f ,   r e s p o n s e ) : 
 
                 p a s s 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   s e t t i n g s * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         " " " 
 
         I f   y o u   u s e   t h e   r e d i s   s e r v e r   a s   t h e   s c h e d u l e r ,   t h e   R E D I S _ U R L   m u s t   b e   c o n f i g u r e d . 
 
         " " " 
 
         R E D I S _ U R L   =   ' r e d i s : / / u s e r : p a s s w o r d @ r e d i s _ a d d r e s s : p o r t ' 
 
         R E D I S _ P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         C O N C U R R E N T _ R E Q U E S T S   =   3 2 
 
         C O N C U R R E N T _ W O R D S   =   3 2 
 
         D E F A U L T _ T I M E O U T   =   2 0 
 
         D E F A U L T _ H E A D E R S   =   { 
 
                 ' A c c e p t ' :   ' t e x t / h t m l , a p p l i c a t i o n / x h t m l + x m l , a p p l i c a t i o n / x m l ; q = 0 . 9 , * / * ; q = 0 . 8 ' , 
 
                 ' A c c e p t - L a n g u a g e ' :   ' z h - C N ' , 
 
         } 
 
 
 
         D O W N L O A D _ D A L E Y   =   0 
 
         P R O C E S S _ D A L E Y   =   0 . 0 1 
 
         D O W N L O A D E R _ M I D D L E W A R E S   =   [ 
 
                 ( D e m o M i d d l e w a r e ,   3 0 0 ) , 
 
 
 
         ] 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   i t e m s * *   
 
 ` ` ` p y t h o n 
 
 f r o m   a i o c r a w l e r   i m p o r t   I t e m ,   F i e l d 
 
 
 
 
 
 c l a s s   D e m o I t e m ( I t e m ) : 
 
         " " " 
 
         y o u   c a n   d e f i n e   y o u r   I t e m   l i k e   t h i s ,   j u s t   l i k e   s c r a p y   I t e m : 
 
         n a m e   =   F i e l d ( ) 
 
         w e b s i t e   =   F i e l d ( ) 
 
         " " " 
 
         i t e m _ n a m e   =   " d e m o " 
 
         p a s s 
 
 ` ` ` 
 
 # # #   r u n   t h e   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   r u n   d e m o 
 
 ` ` ` 
 
 # # #   E x p o r t   t h e   I t e m   f r o m   t h e   r e d i s   s e r v e r   t o   a   l o c a l   c s v   f i l e   o r   r e m o t e   m o n g o   s e v e r 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o 
 
 ` ` ` 
 
 * * I f   y o u   c o n f i g u r e   M O N G O _ H O S T   i n   y o u r   s e t t i n g s ,   i t   w i l l   b e   e x p o r t e d   t o   m o n g o   s e v e r   b y   d e f a u l t . * * 
 
 ` ` ` p y t h o n 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
         
 
         #   o t h e r   i n f o r m a t i o n . . . 
 
         M O N G O _ H O S T   =   ' y o u r   m o n g o   s e v e r   a d d r e s s ' 
 
         M O N G O _ P O R T   =   2 7 0 1 7 
 
         M O N G O _ U S E R   =   " m o n g o   u s e r n a m e " 
 
         M O N G O _ P A S S W O R D   =   " m o n g o   p a s s w o r d " 
 
         M O N G O _ D B   =   N o n e   #   I f   y o u   d o n ' t   c o n f i g u r e   M O N G O _ D B ,   i t   w i l l   b e   s e t   t o   t h e   p r o j e c t   n a m e   b y   d e f a u l t .         
 
 
 
 ` ` ` 
 
 * * Y o u   c a n   a l s o   s p e c i f y   t h e   f i l e   n a m e   a n d   t h e   o u t p u t   t y p e . * * 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o   - - f i l e n a m e   d a t a . c s v   - - t y p e   c s v 
 
 ` ` ` 
 
 * * E x p o r t   t o   a   r e m o t e   m o n g o   s e r v e r * * 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o   - - t y p e   m o n g o 
 
 ` ` ` 
 
 [ d o c _ c n ] :   # 
 
 [ d o c _ e n ] :   # 
 
 
 
 

==> aiocrawler-1.21.tar.gz: aiocrawler-1.21/README.md <==
< d i v   a l i g n = " l e f t " > 
 
 < i m g   s r c = " h t t p s : / / g i t h u b . c o m / k y l i n 1 0 2 0 / a i o c r a w l e r / b l o b / m a s t e r / l o g o . p n g "   h e i g h t = " 1 2 8 "   w i d t h = " 1 2 8 "   > 
 
   < / d i v > 
 
 
 
 ! [ v e r s i o n ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / v e r s i o n - v 1 . 2 1 - g r e e n . s v g ) 
 
 ! [ s u p p o r t ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / p y t h o n - 3 . 6 % 2 0 % 7 C % 2 0 3 . 7 - b l u e . s v g ) 
 
 ! [ l i c e n s e ] ( h t t p s : / / i m g . s h i e l d s . i o / b a d g e / l i c e n s e - M I T - y e l l o w . s v g ) 
 
 
 
 # # # #   A i o c r a w l e r   i s   a n   a s y n c h r o n o u s ,   d i s t r i b u t e d   c r a w l e r   f r a m e w o r k ,   b a s e d   o n   r e d i s ,   a s y n c i o ,   a i o h t t p . 
 
 * * D i f f e r e n t   f r o m   s c r a p y ,   A i o c r a w l e r   s t a r t s   w i t h   a   s e r i e s   o f   w o r d s , 
 
 g e n e r a t e s   u r l s   b a s e d   o n   w o r d s   a n d   s t a r t s   c r a w l i n g   i n s t e a d   o f 
 
 s t a r t _ u r l s * * 
 
 
 
 ! [ i m a g e ] ( h t t p s : / / g i t h u b . c o m / k y l i n 1 0 2 0 / a i o c r a w l e r - d e m o / b l o b / m a s t e r / c r e d i t . g i f ) 
 
 
 
 
 
 -   [ -Neech] [ d o c _ c n ]   |   [ d o c u m e n t a t i o n ] [ d o c _ e n ] 
 
 -   # # #   I n s t a l l a t i o n 
 
 ` ` ` b a s h 
 
 p i p 3   i n s t a l l   a i o c r a w l e r 
 
 ` ` ` 
 
 Y o u   c a n   a l s o   i n s t a l l   b y   t h i s   w a y 
 
 ` ` ` b a s h 
 
 p y t h o n 3   s e t u p . p y   i n s t a l l 
 
 ` ` ` 
 
 
 
 -   # # #   s t a r t   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   s t a r t p r o j e c t   d e m o 
 
 ` ` ` 
 
 * * T h i s   w i l l   c r e a t e   a   d e m o   d i r e c t o r y   w i t h   t h e   f o l l o w i n g   c o n t e n t s * * 
 
 ` ` ` 
 
 + - -   d e m o / 
 
 |         + - -   i t e m s . p y 
 
 |         + - -   m i d d l e w a r e s . p y 
 
 |         + - -   r u n . p y 
 
 |         + - -   s e t t i n g s . p y 
 
 |         + - -   s p i d e r s . p y 
 
 ` ` ` 
 
 * * T h i s   i s   t h e   c o d e   f o r   y o u r   f i r s t   S p i d e r * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s ,   S p i d e r ,   R e q u e s t 
 
 
 
 
 
 c l a s s   D e m o S p i d e r ( S p i d e r ) : 
 
         n a m e   =   " d e m o " 
 
 
 
         d e f   _ _ i n i t _ _ ( s e l f ,   s e t t i n g s :   B a s e S e t t i n g s ) : 
 
                 S p i d e r . _ _ i n i t _ _ ( s e l f ,   s e t t i n g s ) 
 
 
 
         d e f   m a k e _ r e q u e s t ( s e l f ,   w o r d ) : 
 
                 r e t u r n   R e q u e s t ( w o r d ,   c a l l b a c k = s e l f . p a r s e ) 
 
 
 
         d e f   p a r s e ( s e l f ,   r e s p o n s e ) : 
 
                 p a s s 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   s e t t i n g s * * 
 
 ` ` ` p y t h o n 
 
 #   c o d i n g :   u t f - 8 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         " " " 
 
         I f   y o u   u s e   t h e   r e d i s   s e r v e r   a s   t h e   s c h e d u l e r ,   t h e   R E D I S _ U R L   m u s t   b e   c o n f i g u r e d . 
 
         " " " 
 
         R E D I S _ U R L   =   ' r e d i s : / / u s e r : p a s s w o r d @ r e d i s _ a d d r e s s : p o r t ' 
 
         R E D I S _ P R O J E C T _ N A M E   =   ' d e m o ' 
 
 
 
         C O N C U R R E N T _ R E Q U E S T S   =   3 2 
 
         C O N C U R R E N T _ W O R D S   =   3 2 
 
         D E F A U L T _ T I M E O U T   =   2 0 
 
         D E F A U L T _ H E A D E R S   =   { 
 
                 ' A c c e p t ' :   ' t e x t / h t m l , a p p l i c a t i o n / x h t m l + x m l , a p p l i c a t i o n / x m l ; q = 0 . 9 , * / * ; q = 0 . 8 ' , 
 
                 ' A c c e p t - L a n g u a g e ' :   ' z h - C N ' , 
 
         } 
 
 
 
         D O W N L O A D _ D A L E Y   =   0 
 
         P R O C E S S _ D A L E Y   =   0 . 0 1 
 
         D O W N L O A D E R _ M I D D L E W A R E S   =   [ 
 
                 ( D e m o M i d d l e w a r e ,   3 0 0 ) , 
 
 
 
         ] 
 
 ` ` ` 
 
 * * C o n f i g u r e   y o u r   i t e m s * *   
 
 ` ` ` p y t h o n 
 
 f r o m   a i o c r a w l e r   i m p o r t   I t e m ,   F i e l d 
 
 
 
 
 
 c l a s s   D e m o I t e m ( I t e m ) : 
 
         " " " 
 
         y o u   c a n   d e f i n e   y o u r   I t e m   l i k e   t h i s ,   j u s t   l i k e   s c r a p y   I t e m : 
 
         n a m e   =   F i e l d ( ) 
 
         w e b s i t e   =   F i e l d ( ) 
 
         " " " 
 
         i t e m _ n a m e   =   " d e m o " 
 
         p a s s 
 
 ` ` ` 
 
 # # #   r u n   t h e   p r o j e c t 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   r u n   d e m o 
 
 ` ` ` 
 
 # # #   E x p o r t   t h e   I t e m   f r o m   t h e   r e d i s   s e r v e r   t o   a   l o c a l   c s v   f i l e   o r   r e m o t e   m o n g o   s e v e r 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o 
 
 ` ` ` 
 
 * * I f   y o u   c o n f i g u r e   M O N G O _ H O S T   i n   y o u r   s e t t i n g s   o r   t h e   E n v i r o n m e n t a l   v a r i a b l e s ,   i t   w i l l   b e   e x p o r t e d   t o   m o n g o   s e v e r   b y   d e f a u l t . * * 
 
 ` ` ` p y t h o n 
 
 f r o m   a i o c r a w l e r   i m p o r t   B a s e S e t t i n g s 
 
 f r o m   d e m o . m i d d l e w a r e s   i m p o r t   D e m o M i d d l e w a r e 
 
 
 
 
 
 c l a s s   D e m o S e t t i n g s ( B a s e S e t t i n g s ) : 
 
         P R O J E C T _ N A M E   =   ' d e m o ' 
 
         
 
         #   o t h e r   i n f o r m a t i o n . . . 
 
         M O N G O _ H O S T   =   ' y o u r   m o n g o   s e v e r   a d d r e s s ' 
 
         M O N G O _ P O R T   =   2 7 0 1 7 
 
         M O N G O _ U S E R   =   " m o n g o   u s e r n a m e " 
 
         M O N G O _ P A S S W O R D   =   " m o n g o   p a s s w o r d " 
 
         M O N G O _ D B   =   N o n e   #   I f   y o u   c o n f i g u r e   M O N G O _ H O S T   i n   y o u r   s e t t i n g s   o r   t h e   E n v i r o n m e n t a l   v a r i a b l e s ,   i t   w i l l   b e   e x p o r t e d   t o   m o n g o   s e v e r   b y   d e f a u l t .         
 
 
 
 ` ` ` 
 
 * * Y o u   c a n   a l s o   s p e c i f y   t h e   f i l e   n a m e   a n d   t h e   o u t p u t   t y p e . * * 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o   - - f i l e n a m e   d a t a . c s v   - - t y p e   c s v 
 
 ` ` ` 
 
 * * E x p o r t   t o   a   r e m o t e   m o n g o   s e r v e r * * 
 
 ` ` ` b a s h 
 
 a i o c r a w l e r   o u t p u t   d e m o   - - t y p e   m o n g o 
 
 ` ` ` 
 
 [ d o c _ c n ] :   # 
 
 [ d o c _ e n ] :   # 
 
 
 
 
